==> djaodjin-survey-0.7.5.tar.gz: djaodjin-survey-0.7.5/survey/urls/views/matrices.py <==
# Copyright (c) 2022, DjaoDjin inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from ...views.matrix import (MatrixListView, MatrixDetailView,
    AccountListView, QuestionListView)
from ...compat import path


urlpatterns = [
    path('accounts/<slug:editable_filter>/',
        AccountListView.as_view(), name='accounts_list'),
    path('accounts/',
        AccountListView.as_view(), name='accounts_base'),
    path('questions/<slug:editable_filter>/',
        QuestionListView.as_view(), name='questions_list'),
    path('questions/',
        QuestionListView.as_view(), name='questions_base'),
    path('<path:path>/',
        MatrixDetailView.as_view(), name='matrix_chart'),
    path('',
        MatrixListView.as_view(), name='matrix_base'),
]

==> djaodjin-survey-0.10.1.tar.gz: djaodjin-survey-0.10.1/survey/urls/views/matrices.py <==
# Copyright (c) 2023, DjaoDjin inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from ...views.matrix import (CompareView, MatrixListView, MatrixDetailView,
    AccountListView, QuestionListView)
from ...compat import path


urlpatterns = [
    path('accounts/<slug:editable_filter>/',
        AccountListView.as_view(), name='accounts_list'),
    path('accounts/',
        AccountListView.as_view(), name='accounts_base'),
    path('questions/<slug:editable_filter>/',
        QuestionListView.as_view(), name='questions_list'),
    path('questions/',
        QuestionListView.as_view(), name='questions_base'),
    path('compare/',
        CompareView.as_view(), name='matrix_compare'),
    path('<path:path>/',
        MatrixDetailView.as_view(), name='matrix_chart'),
    path('',
        MatrixListView.as_view(), name='matrix_base'),
]
